@@ -507,9 +507,9 @@ class Emitter(object):
             self.indent = self.indents.pop()
             self.flow_level -= 1
             self.write_indicator(u'}', False)
-            # if self.event.comment and self.event.comment[0]:
-            #     # eol comment on flow sequence
-            #     self.write_post_comment(self.event)
+            if self.event.comment and self.event.comment[0]:
+                # eol comment on empty mapping
+                self.write_post_comment(self.event)
             self.state = self.states.pop()
         else:
             if self.canonical or self.column > self.best_width:
@@ -534,7 +534,7 @@ class Emitter(object):
                 self.write_indent()
             self.write_indicator(u'}', False)
             if self.event.comment and self.event.comment[0]:
-                # eol comment on flow mapping
+                # eol comment on flow mapping, never reached on empty mappings
                 self.write_post_comment(self.event)
             self.state = self.states.pop()
         else:
@@ -579,10 +579,11 @@ class Emitter(object):
         # type: (bool) -> None
         if not first and isinstance(self.event, SequenceEndEvent):
             if self.event.comment and self.event.comment[1]:
-                # final comments from a doc
+                # final comments on a block list e.g. empty line
                 self.write_pre_comment(self.event)
             self.indent = self.indents.pop()
             self.state = self.states.pop()
+            self.no_newline = False
         else:
             if self.event.comment and self.event.comment[1]:
                 self.write_pre_comment(self.event)
@@ -620,7 +621,9 @@ class Emitter(object):
                 self.write_pre_comment(self.event)
             self.write_indent()
             if self.check_simple_key():
-                if not isinstance(self.event, SequenceStartEvent):  # sequence keys
+                if not isinstance(
+                    self.event, (SequenceStartEvent, MappingStartEvent)
+                ):  # sequence keys
                     if self.event.style == '?':
                         self.write_indicator(u'?', True, indention=True)
                 self.states.append(self.expect_block_mapping_simple_value)
@@ -702,6 +705,7 @@ class Emitter(object):
         return length < self.MAX_SIMPLE_KEY_LENGTH and (
             isinstance(self.event, AliasEvent)
             or (isinstance(self.event, SequenceStartEvent) and self.event.flow_style is True)
+            or (isinstance(self.event, MappingStartEvent) and self.event.flow_style is True)
             or (
                 isinstance(self.event, ScalarEvent)
                 and not self.analysis.empty
@@ -1361,7 +1365,7 @@ class Emitter(object):
             if end < len(text):
                 ch = text[end]
             if breaks:
-                if ch is None or ch not in u'\n\x85\u2028\u2029':
+                if ch is None or ch not in u'\n\x85\u2028\u2029\a':
                     if (
                         not leading_space
                         and ch is not None
@@ -1390,12 +1394,16 @@ class Emitter(object):
                         self.stream.write(data)
                     start = end
             else:
-                if ch is None or ch in u' \n\x85\u2028\u2029':
+                if ch is None or ch in u' \n\x85\u2028\u2029\a':
                     data = text[start:end]
                     self.column += len(data)
                     if bool(self.encoding):
                         data = data.encode(self.encoding)
                     self.stream.write(data)
+                    if ch == u'\a':
+                        self.write_line_break()
+                        self.write_indent()
+                        end += 2  # \a and the space that is inserted on the fold
                     if ch is None:
                         self.write_line_break()
                     start = end
@@ -1507,7 +1515,7 @@ class Emitter(object):
                     try:
                         self.stream.write(data)
                     except:  # NOQA
-                        print(repr(data))
+                        sys.stdout.write(repr(data) + '\n')
                         raise
                     start = end
             if ch is not None:
@@ -1518,7 +1526,7 @@ class Emitter(object):
     def write_comment(self, comment):
         # type: (Any) -> None
         value = comment.value
-        # print('{:02d} {:02d} {!r}'.format(self.column, comment.start_mark.column, value))
+        # nprint('{:02d} {:02d} {!r}'.format(self.column, comment.start_mark.column, value))
         if value[-1] == '\n':
             value = value[:-1]
         try:
@@ -1532,7 +1540,7 @@ class Emitter(object):
                 ValueError
         except ValueError:
             col = self.column + 1
-        # print('post_comment', self.line, self.column, value)
+        # nprint('post_comment', self.line, self.column, value)
         try:
             # at least one space if the current column >= the start column of the comment
             # but not at the start of a line
@@ -1566,7 +1574,7 @@ class Emitter(object):
                 if isinstance(event, start_events):
                     comment.pre_done = True
         except TypeError:
-            print('eventtt', type(event), event)
+            sys.stdout.write('eventtt {} {}'.format(type(event), event))
             raise
         return True
 
