@@ -9,9 +9,11 @@ if False:  # MYPY
 
 __all__ = [
     'ScalarString',
-    'PreservedScalarString',
+    'LiteralScalarString',
+    'FoldedScalarString',
     'SingleQuotedScalarString',
     'DoubleQuotedScalarString',
+    'PreservedScalarString',
 ]
 
 
@@ -27,8 +29,8 @@ class ScalarString(text_type):
         return type(self)((text_type.replace(self, old, new, maxreplace)))
 
 
-class PreservedScalarString(ScalarString):
-    __slots__ = ('comment')  # the comment after the | on the first line
+class LiteralScalarString(ScalarString):
+    __slots__ = 'comment'  # the comment after the | on the first line
 
     style = '|'
 
@@ -37,6 +39,19 @@ class PreservedScalarString(ScalarString):
         return ScalarString.__new__(cls, value)
 
 
+PreservedScalarString = LiteralScalarString
+
+
+class FoldedScalarString(ScalarString):
+    __slots__ = ('fold_pos', 'comment')  # the comment after the > on the first line
+
+    style = '>'
+
+    def __new__(cls, value):
+        # type: (Text) -> Any
+        return ScalarString.__new__(cls, value)
+
+
 class SingleQuotedScalarString(ScalarString):
     __slots__ = ()
 
@@ -59,28 +74,44 @@ class DoubleQuotedScalarString(ScalarString):
 
 def preserve_literal(s):
     # type: (Text) -> Text
-    return PreservedScalarString(s.replace('\r\n', '\n').replace('\r', '\n'))
+    return LiteralScalarString(s.replace('\r\n', '\n').replace('\r', '\n'))
 
 
-def walk_tree(base):
-    # type: (Any) -> None
+def walk_tree(base, map=None):
+    # type: (Any, Any) -> None
     """
     the routine here walks over a simple yaml tree (recursing in
     dict values and list items) and converts strings that
     have multiple lines to literal scalars
-    """
-    from ruamel.yaml.compat import string_types
 
-    if isinstance(base, dict):
+    You can also provide an explicit (ordered) mapping for multiple transforms
+    (first of which is executed):
+        map = ruamel.yaml.compat.ordereddict
+        map['\n'] = preserve_literal
+        map[':'] = SingleQuotedScalarString
+        walk_tree(data, map=map)
+    """
+    from ruamel.yaml.compat import string_types, MutableMapping, MutableSequence
+
+    if map is None:
+        map = {'\n': preserve_literal}
+
+    if isinstance(base, MutableMapping):
         for k in base:
             v = base[k]  # type: Text
-            if isinstance(v, string_types) and '\n' in v:
-                base[k] = preserve_literal(v)
+            if isinstance(v, string_types):
+                for ch in map:
+                    if ch in v:
+                        base[k] = map[ch](v)
+                        break
             else:
                 walk_tree(v)
-    elif isinstance(base, list):
+    elif isinstance(base, MutableSequence):
         for idx, elem in enumerate(base):
-            if isinstance(elem, string_types) and '\n' in elem:  # type: ignore
-                base[idx] = preserve_literal(elem)  # type: ignore
+            if isinstance(elem, string_types):
+                for ch in map:
+                    if ch in elem:  # type: ignore
+                        base[idx] = map[ch](elem)
+                        break
             else:
                 walk_tree(elem)
